Force

Enum Force 

pub enum Force {
    No,
    Yes,
    Discard,
}
cursor movement qualifier

There are a few options for cursor movement to branches:

  • Force::No, moves to the branch if it is not empty
  • Force::Yes, forces the move to an empty branch
  • Force::Discard, moves to full or empty branchs, discarding the currently active branch. This will effectively connect the upper node to the lower node, bypassing the current one

Variants



No



Yes



Discard